@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2017 Montel Laurent <montel@kde.org>
+   Copyright (C) 2017-2018 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -26,7 +26,7 @@ class ImportImapSettingsAkonadiPassword : public AbstractImapSettingsPassword
 {
 public:
     ImportImapSettingsAkonadiPassword();
-    ~ImportImapSettingsAkonadiPassword();
+    ~ImportImapSettingsAkonadiPassword() override;
 
     void importPasswords(SieveEditorUtil::SieveServerConfig &config, const QString &filename, bool reuseImapSettings) override;
 };
