@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2016-2017 Montel Laurent <montel@kde.org>
+   Copyright (C) 2016-2018 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -104,19 +104,19 @@ bool ImportImapSettingsThunderbirdCheckJob::importSettings(const QString &direct
     QTextStream stream(&file);
     while (!stream.atEnd()) {
         const QString line = stream.readLine();
-        if (line.startsWith(QStringLiteral("user_pref"))) {
-            if (line.contains(QStringLiteral("mail.server."))
-                || line.contains(QStringLiteral("mail.account."))
-                || line.contains(QStringLiteral("mail.accountmanager."))
-                || line.contains(QStringLiteral("extensions.sieve.account."))) {
+        if (line.startsWith(QLatin1String("user_pref"))) {
+            if (line.contains(QLatin1String("mail.server."))
+                || line.contains(QLatin1String("mail.account."))
+                || line.contains(QLatin1String("mail.accountmanager."))
+                || line.contains(QLatin1String("extensions.sieve.account."))) {
                 insertIntoMap(line);
             }
         } else {
             if (!line.startsWith(QLatin1Char('#'))
                 && line.isEmpty()
-                && line.startsWith(QStringLiteral("/*"))
-                && line.startsWith(QStringLiteral(" */"))
-                && line.startsWith(QStringLiteral(" *"))) {
+                && line.startsWith(QLatin1String("/*"))
+                && line.startsWith(QLatin1String(" */"))
+                && line.startsWith(QLatin1String(" *"))) {
                 qCDebug(SIEVEEDITOR_LOG) << " unstored line :" << line;
             }
         }
